package net.knarcraft.placeholdersigns.config;

import net.knarcraft.knarlib.formatting.TranslatableMessage;
import org.jetbrains.annotations.NotNull;

/**
 * Translatable plugin messages
 */
public enum PlaceholderSignMessage implements TranslatableMessage {

    /**
     * The message to display when waiting for a sign selection (edit)
     */
    SUCCESS_CLICK_SIGN_TO_EDIT,

    /**
     * The message displayed when a player tries to edit a waxed sign without the necessary permission
     */
    ERROR_WAXED_NO_PERMISSION,

    /**
     * The message displayed when a sign line has been successfully changed
     */
    SUCCESS_SIGN_CHANGED,

    /**
     * The format used when printing current sign lines
     */
    SUCCESS_SIGN_CONTENTS,

    /**
     * The string displayed when a sign property is confirmed
     */
    SIGN_PROPERTY_CONFIRM,

    /**
     * The string displayed when a sign property is denied
     */
    SIGN_PROPERTY_DENY,

    /**
     * The message displayed when a player command is used from the console
     */
    ERROR_PLAYER_ONLY,

    /**
     * The message to display when the player is not looking at a sign, which is required
     */
    ERROR_NOT_LOOKING_AT_SIGN,

    /**
     * The message displayed when ready to paste a sign
     */
    SUCCESS_CLICK_SIGN_TO_PASTE,

    /**
     * The message displayed when a sign is successfully pasted
     */
    SUCCESS_SIGN_PASTED,

    /**
     * The message displayed when a protection plugin cancels the sign change event
     */
    ERROR_CANCELLED_BY_PROTECTION,

    /**
     * The message displayed when a sign has been successfully un-waxed
     */
    SUCCESS_SIGN_UN_WAXED,
    ;

    @Override
    public @NotNull TranslatableMessage[] getAllMessages() {
        return PlaceholderSignMessage.values();
    }

}
